==> number-float64-base-to-uint32-0.0.2.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# toUint32

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Convert a [double-precision floating-point number][ieee754] to an unsigned 32-bit integer.

<section class="installation">

## Installation

```bash
npm install @stdlib/number-float64-base-to-uint32
```

</section>

<section class="usage">

## Usage

```javascript
var float64ToUint32 = require( '@stdlib/number-float64-base-to-uint32' );
```

#### float64ToUint32( x )

Converts a [double-precision floating-point number][ieee754] to an unsigned 32-bit integer.

```javascript
var y = float64ToUint32( 4294967297.0 );
// returns 1

y = float64ToUint32( 3.14 );
// returns 3

y = float64ToUint32( -3.14 );
// returns 4294967293

y = float64ToUint32( NaN );
// returns 0

y = float64ToUint32( Infinity );
// returns 0

y = float64ToUint32( -Infinity );
// returns 0
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var randu = require( '@stdlib/random-base-randu' );
var round = require( '@stdlib/math-base-special-round' );
var MAX_INT = require( '@stdlib/constants-uint32-max' );
var float64ToUint32 = require( '@stdlib/number-float64-base-to-uint32' );

var uint32;
var half;
var f64;
var i;

half = ( MAX_INT-1 ) / 2;
for ( i = 0; i < 500; i++ ) {
    // Generate a random double-precision floating-point integer:
    f64 = round( randu()*MAX_INT ) - half;

    // Convert the double-precision floating-point value to an unsigned 32-bit integer:
    uint32 = float64ToUint32( f64 );

    console.log( 'float64: %d => uint32: %d', f64, uint32 );
}
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/number-float64-base-to-uint32.svg
[npm-url]: https://npmjs.org/package/@stdlib/number-float64-base-to-uint32

[test-image]: https://github.com/stdlib-js/number-float64-base-to-uint32/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/number-float64-base-to-uint32/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/number-float64-base-to-uint32/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/number-float64-base-to-uint32?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/number-float64-base-to-uint32
[dependencies-url]: https://david-dm.org/stdlib-js/number-float64-base-to-uint32/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/number-float64-base-to-uint32/main/LICENSE

[ieee754]: https://en.wikipedia.org/wiki/IEEE_754-1985

</section>

<!-- /.links -->

==> number-float64-base-to-uint32-0.0.4.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# toUint32

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Convert a [double-precision floating-point number][ieee754] to an unsigned 32-bit integer.

<section class="installation">

## Installation

```bash
npm install @stdlib/number-float64-base-to-uint32
```

</section>

<section class="usage">

## Usage

```javascript
var float64ToUint32 = require( '@stdlib/number-float64-base-to-uint32' );
```

#### float64ToUint32( x )

Converts a [double-precision floating-point number][ieee754] to an unsigned 32-bit integer.

```javascript
var y = float64ToUint32( 4294967297.0 );
// returns 1

y = float64ToUint32( 3.14 );
// returns 3

y = float64ToUint32( -3.14 );
// returns 4294967293

y = float64ToUint32( NaN );
// returns 0

y = float64ToUint32( Infinity );
// returns 0

y = float64ToUint32( -Infinity );
// returns 0
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var randu = require( '@stdlib/random-base-randu' );
var round = require( '@stdlib/math-base-special-round' );
var MAX_INT = require( '@stdlib/constants-uint32-max' );
var float64ToUint32 = require( '@stdlib/number-float64-base-to-uint32' );

var uint32;
var half;
var f64;
var i;

half = ( MAX_INT-1 ) / 2;
for ( i = 0; i < 500; i++ ) {
    // Generate a random double-precision floating-point integer:
    f64 = round( randu()*MAX_INT ) - half;

    // Convert the double-precision floating-point value to an unsigned 32-bit integer:
    uint32 = float64ToUint32( f64 );

    console.log( 'float64: %d => uint32: %d', f64, uint32 );
}
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/number-float64-base-to-uint32.svg
[npm-url]: https://npmjs.org/package/@stdlib/number-float64-base-to-uint32

[test-image]: https://github.com/stdlib-js/number-float64-base-to-uint32/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/number-float64-base-to-uint32/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/number-float64-base-to-uint32/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/number-float64-base-to-uint32?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/number-float64-base-to-uint32.svg
[dependencies-url]: https://david-dm.org/stdlib-js/number-float64-base-to-uint32/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/number-float64-base-to-uint32/main/LICENSE

[ieee754]: https://en.wikipedia.org/wiki/IEEE_754-1985

</section>

<!-- /.links -->
